==> mall-center-api-0.1.11-20211115.094417-2-sources.jar: cn/com/duiba/mall/center/api/domain/dto/fulcredits/FulcreditsConsumerLimitRecordOnlyDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.fulcredits;

import java.io.Serializable;
import java.util.Date;

/**
* 满赠活动用户唯一性检验表
*/
public class FulcreditsConsumerLimitRecordOnlyDto implements Serializable {

    private static final long serialVersionUID = -6640314344715724271L;
    /**
    * 
    */
    private Long id;

    /**
    * 
    */
    private Long consumerId;

    /**
    * 活动id
    */
    private String actId;

    /**
    * 业务类型
    */
    private String bizType;

    /**
    * 来源订单id
    */
    private Long sourceId;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setActId(String actId) {
        this.actId = actId;
    }

    public String getActId() {
        return actId;
    }

    public void setBizType(String bizType) {
        this.bizType = bizType;
    }

    public String getBizType() {
        return bizType;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }
}

==> mall-center-api-0.1.32-sources.jar: cn/com/duiba/mall/center/api/domain/dto/fulcredits/FulcreditsConsumerLimitRecordOnlyDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.fulcredits;

import java.io.Serializable;
import java.util.Date;

/**
* 满赠活动用户唯一性检验表
*/
public class FulcreditsConsumerLimitRecordOnlyDto implements Serializable {

    private static final long serialVersionUID = -6640314344715724271L;
    /**
    * 
    */
    private Long id;

    /**
    * 
    */
    private Long consumerId;

    /**
    * 活动id
    */
    private Long actId;

    /**
    * 业务类型
    */
    private String bizType;

    /**
    * 来源订单id
    */
    private Long sourceId;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public Long getActId() {
        return actId;
    }

    public void setBizType(String bizType) {
        this.bizType = bizType;
    }

    public String getBizType() {
        return bizType;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }
}
